@@ -13,8 +13,6 @@ f_makeErrorTable <- function(data,
   
 {
   
-  # browser()
-  
   # get colnames if available, otherwise fill in 1:p
   if(is.null(colnames(data))) {
     cnames <- 1:p
@@ -360,7 +358,6 @@ predict.mgm <- function(object, # One of the four mgm objects
         
         # ----- Make Predictions -----
         
-        
         object_ep <- object$tvmodels[[ep]]
         class(object_ep) <- cobj_ep
       
@@ -369,18 +366,17 @@ predict.mgm <- function(object, # One of the four mgm objects
                                                       data = data, 
                                                       consec = consec)
         
-        if(!is.null(consec)) n_pred <- sum(corePred$included) #+ 1 # this is stupid; the $included should better be defined on all rows
-        
-        # browser()
+        # if(!is.null(consec)) 
+        if(cobj == 'tvmvar') n_pred <- sum(corePred$included) else { n_pred <- n}
         
         # Save separate for output:
         l_preds[[ep]] <- do.call(cbind, corePred$pred)
         l_probs[[ep]] <- corePred$prob
         l_true[[ep]] <- corePred$true
         
-        # Save weights (subset by consec, if provided)
+        # Save weights (subset by consec, if provided, if mVAR model)
         wo <- object_ep$call$weights
-        if(!is.null(consec)) wo <- wo[corePred$included]
+        if(cobj == 'tvmvar') wo <- wo[corePred$included] 
         l_weights[[ep]] <- wo
 
       } # end for: estpoints
@@ -390,19 +386,15 @@ predict.mgm <- function(object, # One of the four mgm objects
       
       # add up weights
       m_weights <- do.call(cbind, l_weights)
-      
       v_weights <- rowSums(m_weights)
       
       p_ind_con <- which(type != 'c')
       p_ind_cat <- which(type == 'c')
       
-      
       # Storage
       l_w_predict_cat <- list()
       a_w_predict_con <- array(NA, dim = c(n_pred, length(p_ind_con), n_estpoints))
       
-      # browser()
-      
       # --- Continuous Variables ---
       
       if(length(p_ind_con) > 0) {
@@ -491,54 +483,9 @@ predict.mgm <- function(object, # One of the four mgm objects
       true <- corePred$true
       
       
-      
-      # ----- Calculate Errors -----
-      
-      
-      # I think can now be done as in stationary case; maybe simplify code, s.t. error computation is outside the tv/stationary method
-      
-      
-      # m_pred <- do.call(cbind, corePred$pred) # Collapse predictions in matrix
-      # v_error <- v_errortype <- rep(NA, p) # Create Storage
-      # 
-      # 
-      # # Errors Continuous
-      # l_errors_con <- list()
-      # if(!is.null(l_errorCon)) {
-      #   for(e in 1:length(l_errorCon)) {
-      #     v_errors <- rep(NA, p)
-      #     for(j in 1:p)  if(type[j] != 'c')  v_errors[j] <- l_errorCon[[e]](true = corePred$true[, j],
-      #                                                                       pred = m_pred[, j],
-      #                                                                       weights = object$tvmodels[[ep]]$call$weights)
-      #     l_errors_con[[e]] <- v_errors
-      #   }
-      #   names(l_errors_con) <- names(l_errorCon)
-      # }
-      # l_errors_ep_con[[ep]] <- l_errors_con
-      # 
-      # # Errors Categorical
-      # l_errors_cat <- list()
-      # if(!is.null(l_errorCat)) {
-      #   for(e in 1:length(l_errorCat)) {
-      #     v_errors <- rep(NA, p)
-      #     for(j in 1:p)  if(type[j] == 'c')  v_errors[j] <- l_errorCat[[e]](true = corePred$true[, j],
-      #                                                                       pred = m_pred[, j],
-      #                                                                       weights = object$tvmodels[[ep]]$call$weights)
-      #     l_errors_cat[[e]] <- v_errors
-      #   }
-      #   names(l_errors_cat) <- names(l_errorCat)
-      # }
-      # l_errors_ep_cat[[ep]] <- l_errors_cat
-      
-      
-      
-      # Aggregate: across estimation points - yes!
-      
-      
     } # end if: tvMethod weighted?
     
     
-    
     # ++++++++++ Prediction Option B.1: 'closestModel' ++++++++++
     
     if(tvMethod == 'closestModel') {
@@ -593,41 +540,14 @@ predict.mgm <- function(object, # One of the four mgm objects
       preds <- do.call(rbind, l_preds)
       probs <- l_probs
       true <- do.call(rbind, l_true)
-      
-      
-      # ----- Calculate Errors (as in stationary case, actually) -----
-      
-      # # Errors Continuous
-      # l_errors_con <- list()
-      # if(!is.null(l_errorCon)) {
-      #   for(e in 1:length(l_errorCon)) {
-      #     v_errors <- rep(NA, p)
-      #     for(j in 1:p)  if(type[j] != 'c')  v_errors[j] <- l_errorCon[[e]](TrueAll[, j], PredAll[, j])
-      #     l_errors_con[[e]] <- v_errors
-      #   }
-      #   names(l_errors_con) <- names(l_errorCon)
-      # }
-      # 
-      # # Errors Categorical
-      # l_errors_cat <- list()
-      # if(!is.null(l_errorCat)) {
-      #   for(e in 1:length(l_errorCat)) {
-      #     v_errors <- rep(NA, p)
-      #     for(j in 1:p)  if(type[j] == 'c')  v_errors[j] <- l_errorCat[[e]](TrueAll[, j], PredAll[, j])
-      #     l_errors_cat[[e]] <- v_errors
-      #   }
-      #   names(l_errors_cat) <- names(l_errorCat)
-      # }
-      
-      
+
     } # end if: tvMethod closestModel?
     
     
   } # end if: time-varying?
   
-  # browser()
-  
   
+
   # ---------- Compute Nodewise Errors ----------
   
   # input: true and preds!
@@ -656,9 +576,6 @@ predict.mgm <- function(object, # One of the four mgm objects
   }
   
   
-  # browser()
-  
-  
   # ---------- Compute time-varying Nodewise Errors ----------
   
   if(tvMethod == "weighted") {
@@ -666,30 +583,64 @@ predict.mgm <- function(object, # One of the four mgm objects
     l_tverrors <- list()
     
     for(ep in 1:n_estpoints) {
-      
+
       object_ep <- object$tvmodels[[ep]]
       
-      # Errors Continuous
+      # --- Compute weights (needed if new data is used, otherwise I could use weights_design from the model object) ---
+      
+      # Get time vector as basis for weighting
+      n_pred <- nrow(true)
+      if(is.null(object$call$timepoints)) {
+        timepoints <- seq(0, 1, length = n_pred)
+      } else {
+        
+        a_w_predict_con[, , ep]
+        
+        # Adapt timepoints to time-varying mVAR/MGM      
+        if(cobj == 'tvmvar') {
+          timepoints <- object$call$timepoints[corePred$included]
+        } else {
+          timepoints <- object$call$timepoints
+        }
+
+      }
+      
+      # Compute weighting as function of estimation point and abndwidth
+      weights <- dnorm(x = timepoints, 
+                       mean = object$call$estpoints[ep], 
+                       sd = object$call$bandwidth)
+              
+
+      # --- Errors Continuous ---
+      
       l_errors_con_tv <- list()
+      # Are any error functions specified?
       if(!is.null(l_errorCon)) {
+        # Loop over error functions
         for(e in 1:length(l_errorCon)) {
           v_errors <- rep(NA, p)
+          # Loop over p variables
           for(j in 1:p)  if(type[j] != 'c')  v_errors[j] <- l_errorCon[[e]](true = true[, j], 
                                                                             pred = l_preds[[ep]][, j], 
-                                                                            weights = object_ep$call$weights_design)
+                                                                            weights = weights)
           l_errors_con_tv[[e]] <- v_errors
         }
         names(l_errors_con_tv) <- names(l_errorCon)
       }
       
-      # Errors Categorical
+      
+      # --- Errors Categorical ---
+      
       l_errors_cat_tv <- list()
+      # Are any error functions specified?
       if(!is.null(l_errorCat)) {
+        # Loop over error functions
         for(e in 1:length(l_errorCat)) {
           v_errors <- rep(NA, p)
+          # Loop over p variables
           for(j in 1:p)  if(type[j] == 'c')  v_errors[j] <- l_errorCat[[e]](true = true[, j], 
                                                                             pred = preds[, j],
-                                                                            weights = object_ep$call$weights_design)
+                                                                            weights = weights)
           l_errors_cat_tv[[e]] <- v_errors
         }
         names(l_errors_cat_tv) <- names(l_errorCat)
